@@ -17,6 +17,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import ros_cdk_core
@@ -33,7 +35,7 @@ class Pipeline(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "PipelineProps",
+        props: typing.Union["PipelineProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::MPS::Pipeline``.
@@ -47,9 +49,15 @@ class Pipeline(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Pipeline.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrPipelineId")
     def attr_pipeline_id(self) -> ros_cdk_core.IResolvable:
         '''Attribute PipelineId: The ID of the MPS queue.'''
@@ -73,7 +81,7 @@ class PipelineProps:
         self,
         *,
         name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosPipeline.NotifyConfigProperty"]] = None,
+        notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosPipeline.NotifyConfigProperty", typing.Dict[str, typing.Any]]]] = None,
         role: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         speed: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         speed_level: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
@@ -88,6 +96,14 @@ class PipelineProps:
         :param speed_level: Property speedLevel: Speed level.
         :param state: Property state: The new state of the MPS queue. Active: The MPS queue is active. Jobs in the MPS queue can be scheduled and run by MPS. Paused: The MPS queue is paused. Jobs in the MPS queue cannot be scheduled or run by MPS, and all jobs remain in the Submitted state. Jobs that are running will not be affected.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PipelineProps.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument notify_config", value=notify_config, expected_type=type_hints["notify_config"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument speed", value=speed, expected_type=type_hints["speed"])
+            check_type(argname="argument speed_level", value=speed_level, expected_type=type_hints["speed_level"])
+            check_type(argname="argument state", value=state, expected_type=type_hints["state"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
@@ -196,7 +212,7 @@ class RosPipeline(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosPipelineProps",
+        props: typing.Union["RosPipelineProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::MPS::Pipeline``.
@@ -206,6 +222,12 @@ class RosPipeline(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosPipeline.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -216,15 +238,18 @@ class RosPipeline(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosPipeline._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrPipelineId")
     def attr_pipeline_id(self) -> ros_cdk_core.IResolvable:
         '''
@@ -232,21 +257,24 @@ class RosPipeline(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrPipelineId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "enable_resource_property_constraint").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -260,9 +288,12 @@ class RosPipeline(
 
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notifyConfig")
     def notify_config(
         self,
@@ -280,9 +311,12 @@ class RosPipeline(
         self,
         value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosPipeline.NotifyConfigProperty"]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "notify_config").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "notifyConfig", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="role")
     def role(
         self,
@@ -297,9 +331,12 @@ class RosPipeline(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "role").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "role", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="speed")
     def speed(
         self,
@@ -322,9 +359,12 @@ class RosPipeline(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "speed").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "speed", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="speedLevel")
     def speed_level(
         self,
@@ -339,9 +379,12 @@ class RosPipeline(
         self,
         value: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "speed_level").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "speedLevel", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="state")
     def state(
         self,
@@ -360,6 +403,9 @@ class RosPipeline(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosPipeline, "state").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "state", value)
 
     @jsii.data_type(
@@ -378,6 +424,10 @@ class RosPipeline(
             :param queue_name: 
             :param topic: 
             '''
+            if __debug__:
+                type_hints = typing.get_type_hints(RosPipeline.NotifyConfigProperty.__init__)
+                check_type(argname="argument queue_name", value=queue_name, expected_type=type_hints["queue_name"])
+                check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
             self._values: typing.Dict[str, typing.Any] = {}
             if queue_name is not None:
                 self._values["queue_name"] = queue_name
@@ -433,7 +483,7 @@ class RosPipelineProps:
         self,
         *,
         name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
-        notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosPipeline.NotifyConfigProperty]] = None,
+        notify_config: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosPipeline.NotifyConfigProperty, typing.Dict[str, typing.Any]]]] = None,
         role: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         speed: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         speed_level: typing.Optional[typing.Union[jsii.Number, ros_cdk_core.IResolvable]] = None,
@@ -448,6 +498,14 @@ class RosPipelineProps:
         :param speed_level: 
         :param state: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosPipelineProps.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument notify_config", value=notify_config, expected_type=type_hints["notify_config"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
+            check_type(argname="argument speed", value=speed, expected_type=type_hints["speed"])
+            check_type(argname="argument speed_level", value=speed_level, expected_type=type_hints["speed_level"])
+            check_type(argname="argument state", value=state, expected_type=type_hints["state"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
